==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/LocalSubjectAccessReviewBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class LocalSubjectAccessReviewBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview,io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewBuilder> {

    io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent;
    Boolean validationEnabled;

    public LocalSubjectAccessReviewBuilder() {
        this(true);
    }

    public LocalSubjectAccessReviewBuilder(Boolean validationEnabled) {
        this(new LocalSubjectAccessReview(), validationEnabled);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent) {
        this(fluent, true);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new LocalSubjectAccessReview(), validationEnabled);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance) {
        this(fluent, instance, true);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance) {
        this(instance,true);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview build() {
        LocalSubjectAccessReview buildable = new LocalSubjectAccessReview(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        LocalSubjectAccessReviewBuilder that = (LocalSubjectAccessReviewBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.4.1-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/LocalSubjectAccessReviewBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class LocalSubjectAccessReviewBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview,io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewBuilder> {

    io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public LocalSubjectAccessReviewBuilder() {
        this(true);
    }

    public LocalSubjectAccessReviewBuilder(java.lang.Boolean validationEnabled) {
        this(new LocalSubjectAccessReview(), validationEnabled);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent) {
        this(fluent, true);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new LocalSubjectAccessReview(), validationEnabled);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance) {
        this(fluent, instance, true);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance) {
        this(instance,true);
    }

    public LocalSubjectAccessReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReview build() {
        LocalSubjectAccessReview buildable = new LocalSubjectAccessReview(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        LocalSubjectAccessReviewBuilder that = (LocalSubjectAccessReviewBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
